/******************************************************************************
**
**  Project Name:	A/UX AppleEvent Suite
**     File Name:	AUX-AESuite.h
**
**   Description:	A/UX AppleEvent Suite Definition
**
*******************************************************************************
** %F%  %I%
*******************************************************************************
**
**                     Copyright (c) 1992 Apple Computer, Inc.
**                       UNPUBLISHED -- ALL RIGHTS RESERVED.
**
**  This program is  confidential  and trade secret of  Apple Computer, Inc.
**  The receipt or possession of this program does not convey any rights to
**  reproduce or disclose  its  contents, or to manufacture,  use,  or sell
**  anything that it may discribe, in whole or in part, without the express
**  written consent of Apple Computer, Inc.
**
*******************************************************************************
**                       A U T H O R   I D E N T I T Y
*******************************************************************************
**
**	Initials	Name
**	--------	-----------------------------------------------
**	BRH			Brett R. Halle
**	JSM			Scott Mulligan
**      RDW                     Roger Warner
**
*******************************************************************************
**                      R E V I S I O N   H I S T O R Y
*******************************************************************************
**
**	  Date		Time	Author	Description
**	--------	-----	------	---------------------------------------
**	06/20/92	14:24	BRH		Original implementation.
**	03/01/93	14:54	JSM		Add new AE 'rcmd'
**	07/29/93	10:00	JSM		Add new AEs for Discus
**      10/08/93        11:00   RDW             Add new keys for replies
**
******************************************************************************/

#ifndef __AUXAESuite__
#define __AUXAESuite__

/*
//const OSType keyAEText = 'ktxt';
//const long kAEReplyModeMask = 0x0000000F;// Mask for reply mode
*/

/*****************
//  Event Class  *
//****************/

#define kAEAUXSuite 'A/UX'

/*****************
//  Event Suite  *
//****************/

/* * * * * * * * * * * * * *
// Open process connection *
// * * * * * * * * * * * * */

#define kAEOpenProcessConnection 'oppc'			/* Event ID. */
/*
// Parameters:
*/
#define keyUserID 'uid '		/* User ID: typeChar. */
#define keyPassword 'pswd'		/* Password: typeChar. */
/*
// Reply parameters:
*/
#define keyConnectionID 'cnid'		/* Connection ID: typeLongInteger. */
/*		keyErrorNumber (optional)
//		keyErrorString (optional)
*/

/* * * * * * * * * * * * * *
// Open console connection *
// * * * * * * * * * * * * */

#define kAEOpenConsoleConnection 'opcc'			/* Event ID. */
/*
// Parameters:
//
//		keyUserID
//		keyPassword
//
// Reply parameters:
//
//		keyConnectionID
//		keyErrorNumber (optional)
//		keyErrorString (optional)
*/

/* * * * * * * * * * * *
// Open PTY connection *
// * * * * * * * * * * */

#define kAEOpenPTYConnection 'optc'			/* Event ID. */
/*
// Parameters:
//
//		keyUserID
//		keyPassword
//
// Reply parameters:
//
//		keyConnectionID
//		keyErrorNumber (optional)
//		keyErrorString (optional)
*/

/* * * * * * * * * * *
// Close connection  *
// * * * * * * * * * */

#define kAECloseConnection 'clsc'			/* Event ID. */
/*
// Parameters:
//
//		keyConnectionID
//
// Reply parameters:
//
//		keyErrorNumber (optional)
//		keyErrorString (optional)
*/

/* * * * * * * * * * * * *
// Close all connections *
// * * * * * * * * * * * */

#define kAECloseAllConnections 'clsa'			/* Event ID. */
/*
// Parameters:
//
//		none
//
// Reply parameters:
//
//		keyErrorNumber (optional)
//		keyErrorString (optional)
*/

/* * * * * * * * * * *
// Send process data *
// * * * * * * * * * */

#define kAESendProcessData 'data'			/* Event ID. */
/*
// Parameters:
//
//		keyConnectionID
//		keyAEText
//
// Reply parameters:
//
//		keyErrorNumber (optional)
//		keyErrorString (optional)
*/

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * 
// Acknowledge process data (asynchronous response to SendProcessData  *
// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

#define kAEAckProcessData 'ackd'			/* Event ID. */
/*
// Parameters:
//
//		keyConnectionID
//
// Reply parameters:
//
//		keyErrorNumber (optional)
//		keyErrorString (optional)
*/

/* * * * * * * * *
// Resize window *
// * * * * * * * */

#define kAEResizeWindow 'rszw'			/* Event ID. */
/*
// Parameters:
//
//		keyConnectionID
*/
#define keyWidthInChars 'wdch'			/* typeInteger. */
#define keyHeightInChars 'htch'			/* typeInteger. */
#define keyWidthInPixels 'wdpx'			/* typeInteger. */
#define keyHeightInPixels 'htpx'		/* typeInteger. */
/*
// Reply parameters:
//
//		keyErrorNumber (optional)
//		keyErrorString (optional)
*/

/* * * * * * * * * * * * * * * *
// Get number of sub-processes *
// * * * * * * * * * * * * * * */

#define kAEGetNumberOfSubprocesses 'gtsp'		/* Event ID. */
/*
// Parameters:
//
//		keyConnectionID
//
// Reply parameters:
//
//		keyAEResult
//		keyErrorNumber (optional)
//		keyErrorString (optional)
*/

/* * * * * * * * * * * *
// Get process status  *
// * * * * * * * * * * */

#define kAEProcessStatus 'gtps'				/* Event ID. */
/*
// Parameters:
//
//		keyConnectionID
//
// Reply parameters:
//
//		keyAEResult
//		keyErrorNumber (optional)
//		keyErrorString (optional)
*/

/* * * * * * * * * * * * * *
// Get process device name *
// * * * * * * * * * * * * */

#define kAEGetProcessDeviceName 'gtpd'			/* Event ID. */
/*
// Parameters:
//
//		keyConnectionID
//
// Reply parameters:
//
//		keyAEResult
//		keyErrorNumber (optional)
//		keyErrorString (optional)
*/

/* * * * * * * * * * * * * *
// Run a remote command      *
// * * * * * * * * * * * * */

#define kAERunRemoteCommand 'rcmd'			/* Event ID. */
/*
// Parameters:
//
//		keyAEText "the command to run"
//
// Reply parameters:
//
//		keyAEText "the output from the command"
//		keyErrorNumber (optional)
//		keyErrorString (optional)
*/



/*-------------------------------------------------------------------------*
 *
 *	AppleEvents for DISCUS      ***      AppleEvents for DISCUS
 *
 *-------------------------------------------------------------------------*/

#define kAEInterval 'jint'		/* Event ID. */
#define keyInterval 'tint'		/*typeInteger*/

#define kAEHeartBeat 'hart'		/* Event ID. */
#define kAENull 'null'			/* Event ID. */
#define kAEQuit 'quit'			/* Event ID. */
#define kAEVersion 'dver'		/* Event ID. */
#define keyAEVersion	'verx'	/* typeChar       : Software Version         */
#define keySessionID	'ssID'	/* typeInteger    : Session/Document ID      */

#define kAEJavMsg 'jmsg'		/* Event ID. */
#define keyMessageCode	'msgc'	/* typeInteger    : Discus Message Number    */
#define keyMsgString	'msgs'	/* typeChar       : Optional Message String  */


#endif  /* __AUXAESuite__ */


