//--------------------------------------------------------------------------------------------------
//																				
//	File:			Polevault.r		 											
//																				
//	Description:	Resource File for the Polevault Sample Program.		
//																				
//																				
//	Copyright  1991 - 1992 by Apple Computer, Inc.  All rights reserved.  		
//--------------------------------------------------------------------------------------------------

//--------------------------------------------------------------------------------------------------
// INCLUDE FILES 
//--------------------------------------------------------------------------------------------------

// Standard Includes 

#ifndef __TYPES.R__
#include "Types.r"
#endif

#ifndef __SYSTYPES.R__
#include "SysTypes.r"
#endif

#ifndef __BalloonTypes__
#include "BalloonTypes.r"
#endif

#ifndef __MacAppTypes__
#include "MacAppTypes.r"
#endif

#ifndef __ViewTypes__
#include "ViewTypes.r"
#endif

#if qDebug | qPerform
include "Debug.rsrc" not 'ckid';
#endif

include "MacApp.rsrc" not 'ckid';
include "Palette.rsrc";

// Includes for Building Blocks
 
include "Dialog.rsrc" not 'ckid';      // moved rD  was in the qDebug section above
include "Printing.rsrc" not 'ckid';
include "PolevaultIcePick.rsrc" not 'ckid'; 


// Include Code Resources

include $$Shell("ObjApp")$$Shell("XAppName") 'CODE';

//--------------------------------------------------------------------------------------------------
// CONSTANTS 
//--------------------------------------------------------------------------------------------------
#define kDefaultSize 40
#define kDefaultType 'JFS'
#define kDefaultName 'Untitled'

// Finder Information
// ------------------

#define kApplicationName	$$Shell("XAppName")
#define kSignature			'JVLN'			// Application signature 	(also in doc.h)
#define kFileType			'appl'			// Data file type 			(also in doc.h) 
#define kStationery			'sF01'			// Stationery file type		(also in doc.h) 

// Bundle Constants
// ------------------

#define kBundleID						128
#define kApplicationID					128
#define kDocumentID						129
#define kStationeryID					130

// 'View' resources
// --------------

#define kSkeletonWindowID				kDefaultWindowID
#define phLookupDialog					1203
#define phAboutBox						201
#define kMandelWindowTitles				1001
// Constants for Menu IDs
// ----------------------

#define mMandelMenu	4
#define mPixMenu	5
#define mGridMenu	6

// Command Numbers For Menu Items
// ------------------------------

#define cCommandHandledByApplication	400
#define cGetPPCServerCmd				405
#define cAEHeartBeat					407
#define cAEmndlMsg						408

#define cCommandHandledByDocument		401
#define cTrackerCommand				403


#define cSetLook1	600
#define cSetLook2	601
#define cSetLook4	602
#define cSetLook8	603
#define cSetLook16	604

#define cSetPix8	500
#define cSetPix16	501
#define cSetPix32	502
#define cSetPix64	503


#define cSetGrid320	700
#define cSetGrid512	701
#define cSetGrid640	702

// AE Identifiers							
// ------------------------------			
#define kAECmdSuiteID				'A/UX'
#define kAEmndlMsg 					'mndl'     		
#define kAEHeartBeat 				'hart'     		
#define kCmdAEEvents				1001
#define kCoreEventClass				'aevt'
#define kAEAnswer				'ansr'

//--------------------------------------------------
//  AppleEvents										
//--------------------------------------------------

resource 'aedt' (kCmdAEEvents) {
	{
	kAECmdSuiteID, kAEmndlMsg, cAEmndlMsg;
	kAECmdSuiteID, kAEHeartBeat, cAEHeartBeat;
	}												
};															//new rD 

// STR# resources
// --------------

#define kSkeletonMenuHelp				1000
#define kAlertUserToError				1001

// Text styles
// --------------

#define kSystemTextStyle				1000


// Memory Management Resources
// ---------------------------

#define kSkeletonSeg	1000
#define kSkeletonMem	1000
#define kSkeletonRes	1000

//--------------------------------------------------------------------------------------------------
// RESOURCES FOR MENUS 
//--------------------------------------------------------------------------------------------------

//--------------------------------------------------------------------------------------------------
// Menu Bars 
//--------------------------------------------------------------------------------------------------

resource 'MBAR' (kMBarDisplayed,
#if qNames
kApplicationName,
#endif
	purgeable) {
	{ mApple; mFile; mEdit; mMandelMenu; mPixMenu; mGridMenu }
};

//--------------------------------------------------------------------------------------------------
// Menus 
//--------------------------------------------------------------------------------------------------

include "Defaults.rsrc" 'CMNU' (mApple);	// Grab the default Apple menus
include "Defaults.rsrc" 'CMNU' (mFile);		// Grab the default File menus
include "Defaults.rsrc" 'CMNU' (mEdit);		// Grab the default Edit menu



	

resource 'CMNU' (mMandelMenu,
#if qNames
"Mandel Menu",
#endif
nonpurgeable) {
	mMandelMenu,
	textMenuProc,
	EnablingManagedByMacApp,
	enabled,
	"Look Ahead",
	{	
		"Set Lookahead 1", noIcon, noKey, noMark, plain, cSetLook1;
		"Set Lookahead 2", noIcon, noKey, noMark, plain, cSetLook2;
		"Set Lookahead 4", noIcon, noKey, noMark, plain, cSetLook4;
		"Set Lookahead 8", noIcon, noKey, noMark, plain, cSetLook8;
		"Set Lookahead 16", noIcon, noKey, noMark, plain, cSetLook16;
	}
};

resource 'CMNU' (mPixMenu,
#if qNames
"Pix Menu",
#endif
nonpurgeable) {
	mPixMenu,
	textMenuProc,
	EnablingManagedByMacApp,
	enabled,
	"Square Size",
	{
		"8x8",		noIcon, noKey, noMark, plain, cSetPix8;
		"16x16",	noIcon, noKey, noMark, plain, cSetPix16;
		"32x32",	noIcon, noKey, noMark, plain, cSetPix32;
		"64x64",	noIcon, noKey, noMark, plain, cSetPix64;
	}
};


resource 'CMNU' (mGridMenu,
#if qNames
"Grid Menu",
#endif
nonpurgeable) {
	mGridMenu,
	textMenuProc,
	EnablingManagedByMacApp,
	enabled,
	"Window Size",
	{
		"320x320",	noIcon, noKey, noMark, plain, cSetGrid320;
		"512x512",	noIcon, noKey, noMark, plain, cSetGrid512;
		"640x640",	noIcon, noKey, noMark, plain, cSetGrid640;
	}
};
		

resource 'CMNU' (mBuzzwords,
#if qNames
"Buzzwords",
#endif
nonpurgeable
) {
	mBuzzwords,
	textMenuProc,
	EnablingManagedByMacApp,
	enabled,
	"Buzzwords",
	 {	/* array: 3 elements */
		"Page Setup Change",	noIcon,	noKey,	noMark, plain, cChangePrinterStyle;
		"Typing",				noIcon,	noKey,	noMark,	plain, cTyping;
		"Tracker Command",		noIcon,	noKey,	noMark, plain, cTrackerCommand;
	}
};

#define kLookupBuzz						1012

resource 'STR#' (kLookupBuzz,
#if qNames
"kLookupBuzz",
#endif
purgeable) {
	{
	"Blank";
	"Select a Mandelbrot Server:";
	"unix";
	}
};


//--------------------------------------------------------------------------------------------------
// Balloon Help Resources for Menus 
//--------------------------------------------------------------------------------------------------

#include $$Shell("MALibraries") "HelpStrings.r";

include "Defaults.rsrc"  'hmnu' (mFile);	
include "Defaults.rsrc"  'hmnu' (mEdit);	

resource 'STR#' (kSkeletonMenuHelp, purgeable) { 
	{
		"No help yet for this  item",
		"Help For Menu Title",
		"Help For First Menu Item",
		"Help For Second Menu Item",
		"Help For Third Menu Item",
	}
};


//--------------------------------------------------------------------------------------------------
// RESOURCES FOR VIEWS, DIALOGS, ALERTS etc. 
//--------------------------------------------------------------------------------------------------

//--------------------------------------------------------------------------------------------------
// Error Strings 
//--------------------------------------------------------------------------------------------------
resource 'STR#' (kAlertUserToError) {
	{	/* array StringArray: 3 elements */
		/* [1] */
		"Already locked."
		" So take that!"
		"",
		/* [2] */
		"Unable to get a connection with write permission.",
		/* [3] */
		"Unknown error.",
		/* [4] */
		"4",
		/* [5] */
		"5",
		/* [6] */
		"6",
		/* [7] */
		"7",
		/* [8] */
		"^0 host has not signaled in over 2 minutes. Closing Connection.",
		/* [9]  */
		"Sorry, this version of Discus will not work with the host that you selected. Later, Dude.",
		/* [10] */											//start error messages for discus client -----
		"Sorry, cannot determine the version of the host.  Disconnecting.",
	}
};

//--------------------------------------------------------------------------------------------------
// About Box
//--------------------------------------------------------------------------------------------------

resource 'DITL' (phAboutBox,
#if qNames
"phAboutBox",
#endif
	purgeable) {
	 {	/* array DITLarray: 3 elements */
		/* [1] */
		{160, 182, 180, 262},
		Button {
			enabled,
			"OK"
		};
		/* [2] */
		{10, 75, 150, 316},
		StaticText {
			disabled,
			"Relay Race was just passed on to me' - hardy har harrrr."
			"\n\nThis program was written "
			"with MacApp  1985-1992 Apple Computer, Inc."
		};
		/* [3] */
		{10, 20, 42, 52},
		Icon {
			disabled,
			1
		}
	}
};

include "Defaults.rsrc"  'ALRT' (phAboutApp);	// Grab the default about box

resource 'STR#' (kDefaultCredits,
#if qNames
	"kDefaultCredits",
#endif
	purgeable) {
	 {
	"The great people behind Relay Race";

	"Engineers";
	"Scott Mulligan";
	"rD Pufahl";

	"Quality Engineers";
	"John Caldwell";

	"Managers";
	"Dave Payne";

	"Human Interface Human";
	"Pete Bickford";
	 }
};



//--------------------------------------------------------------------------------------------------
// MultiFinder information
//--------------------------------------------------------------------------------------------------

resource 'SIZE' (-1) {
	saveScreen,
	acceptSuspendResumeEvents,
	enableOptionSwitch,
	canBackground,
	doesActivateOnFGSwitch,
	backgroundAndForeground,
	dontGetFrontClicks,
	ignoreAppDiedEvents,
	is32BitCompatible,
	isHighLevelEventAware,
	localAndRemoteHLEvents,
	notStationeryAware,				
	reserved,
	reserved,
	reserved,
	reserved,
#if qModelFarCode
	575 * 1024,
	550 * 1024,
#elif qDebug
	2500 * 1024,
	2500 * 1024
#else
	2000 * 1024,
	2000 * 1024
#endif
};

//--------------------------------------------------------------------------------------------------
// Icons
//--------------------------------------------------------------------------------------------------

include "Defaults.rsrc"  'ICN#' (kApplicationID);	// MacApp Family large black & white	
include "Defaults.rsrc"  'ICN#' (kDocumentID);		// MacApp Document large black & white
include "Defaults.rsrc"  'ICN#' (kStationeryID);	// MacApp Stationery large black & white	
include "Defaults.rsrc"  'ics#' (kApplicationID);	// MacApp Family small black & white	
include "Defaults.rsrc"  'ics#' (kDocumentID);		// MacApp Document small black & white
include "Defaults.rsrc"  'ics#' (kStationeryID);	// MacApp Stationery small black & white
include "Defaults.rsrc"  'ics4' (kApplicationID);	// MacApp Family small 4 bit
include "Defaults.rsrc"  'ics4' (kDocumentID);		// MacApp Document small 4 bit
include "Defaults.rsrc"  'ics4' (kStationeryID);	// MacApp Stationery small 4 bit
include "Defaults.rsrc"  'ics8' (kApplicationID);	// MacApp Family small 4 bit
include "Defaults.rsrc"  'ics8' (kDocumentID);		// MacApp Document small 4 bit
include "Defaults.rsrc"  'ics8' (kStationeryID);	// MacApp Stationery small 4 bit
include "Defaults.rsrc"  'icl4' (kApplicationID);	// MacApp Family large 4 bit
include "Defaults.rsrc"  'icl4' (kDocumentID);		// MacApp Document large 4 bit
include "Defaults.rsrc"  'icl4' (kStationeryID);	// MacApp Stationery large 4 bit
include "Defaults.rsrc"  'icl8' (kApplicationID);	// MacApp Family large 8 bit
include "Defaults.rsrc"  'icl8' (kDocumentID);		// MacApp Document large 8 bit
include "Defaults.rsrc"  'icl8' (kStationeryID);	// MacApp Stationery large 8 bit

//--------------------------------------------------------------------------------------------------
// Memory usage information for Skeleton
//--------------------------------------------------------------------------------------------------

// See UMemory.h
// -------------

resource 'seg!' (kSkeletonSeg,
#if qNames
kApplicationName,
#endif
	purgeable) {
	{
		"foo";
	}
};

// Additional Memory Requirements
// ------------------------------

resource 'mem!' (kSkeletonMem,
#if qNames
	"Additional Memory Requirements",
#endif
	purgeable) {
	1024 * 0,				// Add to temporary reserve
	1024 * 0,				// Add to permanent reserve
	1024 * 0				// Add to stack space
};

// Additional Resident Segments
// ----------------------------

resource 'res!' (kSkeletonRes,
#if qNames
	kApplicationName,
#endif
	purgeable) {
	{	
		"ARes";
	};
};

//--------------------------------------------------------------------------------------------------
// Icons, Bundles and FRefsOh my! (don't forget the Signature)
//--------------------------------------------------------------------------------------------------

type kSignature as 'STR ';
resource kSignature (0,
#if qNames
"Signature",
#endif
	purgeable) {
	"Polevault 1.0.1 Apple Computer, Inc. 1988-1992"
};

resource 'FREF' (kApplicationID,
#if qNames
"Polevault Application",
#endif
	purgeable) {
	'APPL',
	0,
	""
};

resource 'FREF' (kDocumentID,
#if qNames
"Polevault Document",
#endif
	purgeable) {
	kFileType,
	1,
	""
};

resource 'FREF' (kStationeryID,
#if qNames
"Polevault Stationery",
#endif
	purgeable) {
	kStationery,
	2,
	""
};

resource 'BNDL' (kBundleID,
#if qNames
"Polevault",
#endif
	purgeable) {
	kSignature,
	0,
	{ /* array TypeArray: 2 elements */
		/* [1] */
		'ICN#',
		{ /* array IDArray: 3 elements */
			0, kApplicationID,
			1, kDocumentID,
			2, kStationeryID
		},
		/* [2] */
		'FREF',
		{ /* array IDArray: 3 elements */
			0, kApplicationID,
			1, kDocumentID,
			2, kStationeryID
		}
	}
};

//--------------------------------------------------------------------------------------------------
//  Version resources
//--------------------------------------------------------------------------------------------------

// The revision of this particular file

RESOURCE 'vers' (1,
#if qNames
"File Version",
#endif
	purgeable) {
	0x01,
	0x01,
	0x20, 
	0x00,
	verUs,
	"1.01",
	"Polevault 1.01, Apple Computer, Inc. 1988-1994"
};
include "Defaults.rsrc"  'vers' (2);		// Overall package


//
//--------------------------------------------------------------------------------------------------
// Views 
//--------------------------------------------------------------------------------------------------

//resource 'STR#' (kMandelWindowTitles,
//#if qNames
//"Window titles",
//#endif
//purgeable) {
//	{
//	""
//	}
//};

resource 'TxSt' (kSystemTextStyle, purgeable) {tsPlain, 0, black, ""};

#define kWinWidth	380
#define kWinHeight	380

resource 'View' (kSkeletonWindowID,
#if qNames
"kSkeletonWindowID",
#endif
purgeable) { MAThreeOh, 
	{
	ViewSignatureAndClassname
		{'wind', 534, "", 'WIND', enabled, noIdle, {}, MAThreeOh, 
		{350, -520}, {kWinWidth, kWinHeight}, sizeVariable, sizeVariable, shown, doesntWantToBeTarget, 
		handlesCursor, letsSubViewsHandleCursor, noCursorID, 
		handlesHelp, letsSubViewsHandleHelp, noHelpID, 1, 
		NoDrawingEnvironment {}, 
		AdornerListSignatureAndClassname {NoIdentifier, AdornerList, AdornerElementSize, AdornerElementSizeShift, DynamicArrayAllocationIncrement, {
			AdornFirst, AdornerLocalObject {EraseAdorner}, 
			DrawView, AdornerLocalObject {DrawAdorner}, 
			AdornLast, AdornerLocalObject {ResizeIconAdorner}}}, emptyUserArea, 
		Window {zoomDocProc, 'SKEL', goAwayBox, resizable, ignoreFirstClick, 
			freeOnClosing, disposeOnFree, closesDocument, openWithDocument, dontAdaptToScreen, stagger, forceOnScreen, 
			dontCenter, doesntFloat, doesntHideOnSuspend, generateActivates, filler, kMandelWindowTitles, 1}, 3}, 
	ViewSignatureAndClassname
		{'scrl', 186, "", 'SCLR', enabled, noIdle, {}, MAThreeOh, 
		{0, 0}, {kWinWidth-15, kWinHeight-15}, sizeRelSuperView, sizeRelSuperView, shown, doesntWantToBeTarget, 
		handlesCursor, letsSubViewsHandleCursor, noCursorID, 
		handlesHelp, letsSubViewsHandleHelp, noHelpID, 1, 
		NoDrawingEnvironment {}, 
		NoAdorners {}, emptyUserArea, 
		Scroller {'vCLR', 'hCLR', {0, 0}, {16, 16}, VertConstrain, HorzConstrain, noInset, respondsToFKeys}, 1}, 
	ViewSignatureAndClassname
		{'view', 75, "TPolevaultView", 'SKEL', enabled, noIdle, {}, MAThreeOh, 
		{0, 0}, {24 * 24, 24 * 24}, sizeFixed, sizeFixed, shown, doesntWantToBeTarget, 
		handlesCursor, letsSubViewsHandleCursor, noCursorID, 
		handlesHelp, letsSubViewsHandleHelp, noHelpID, 1, 
		NoDrawingEnvironment {}, 
		NoAdorners {}, emptyUserArea, 
		View {}, 
		NoSubviews}, 
	ViewSignatureAndClassname
		{'ssbr', 101, "", 'hCLR', enabled, noIdle, {}, MAThreeOh, 
		{245, -1}, {16, 417}, sizeVariable, sizeVariable, shown, doesntWantToBeTarget, 
		handlesCursor, letsSubViewsHandleCursor, noCursorID, 
		handlesHelp, letsSubViewsHandleHelp, noHelpID, 1, 
		NoDrawingEnvironment {}, 
		NoAdorners {}, emptyUserArea, 
		ScrollerScrollBar {mVScrollBarHit, notHilited, notDimmed, sizeable, noInset, kSystemTextStyle, dontPreferOutline, h, 0, 0, 39585}, 
		NoSubviews}, 
	ViewSignatureAndClassname
		{'ssbr', 101, "", 'vCLR', enabled, noIdle, {}, MAThreeOh, 
		{-1, 415}, {247, 16}, sizeVariable, sizeVariable, shown, doesntWantToBeTarget, 
		handlesCursor, letsSubViewsHandleCursor, noCursorID, 
		handlesHelp, letsSubViewsHandleHelp, noHelpID, 1, 
		NoDrawingEnvironment {}, 
		NoAdorners {}, emptyUserArea, 
		ScrollerScrollBar {mVScrollBarHit, notHilited, notDimmed, sizeable, noInset, kSystemTextStyle, dontPreferOutline, v, 0, 0, 49755}, 
		NoSubviews}
	}
};
