// UPolevaultView.cp
// Copyright 1991 Apple Computer, Inc.

#ifndef __UPOLEVAULTVIEW__
#include "UPolevaultView.h"
#endif

#ifndef __UMACAPPUTILITIES__
#include "UMacAppUtilities.h"
#endif

#ifndef __UDOCUMENTPolevault__
#include "UDocumentPolevault.h"
#endif

#ifndef __UTRACKERMandel__
#include "UTrackerMandel.h"
#endif

#ifndef __UMENUMGR__
#include "UMenuMgr.h"
#endif

#ifndef __FONTS__
#include "Fonts.h"
#endif

#ifndef __PALETTES__
#include "Palettes.h"
#endif

#include <stdio.h>
extern "C" void debugf(char*, ...);


#define min(a,b) ((a) < (b) ? (a) : (b))

/****************************** Constants ******************************/

const CommandNumber cCommandHandledByView = 402;
	
/****************************** Global Initialization Procedure ******************************/

//--------------------------------------------------------------------------------------------------
#pragma segment DlgInit

pascal void InitUPolevaultView()
{
	// So the linker doesn't dead strip class info 
	macroDontDeadStrip(TPolevaultView);
}

/****************************** TPolevaultView ******************************/

//--------------------------------------------------------------------------------------------------
#pragma segment AOpen

pascal void TPolevaultView::Initialize() // Override 
{
	inherited::Initialize();
	
	fDocumentPolevault = NULL;
	fPaletteFixedYet  = false;
}
	
//--------------------------------------------------------------------------------------------------
#pragma segment AOpen

pascal void TPolevaultView::IPolevaultView(TDocumentPolevault* itsDocument,
										TView* itsSuperView,
						 				const VPoint& itsLocation,
						 				const VPoint& itsSize)
{
	this->IView((TDocument*)itsDocument,itsSuperView,itsLocation,itsSize,sizeFixed, sizeFixed);
	
	fDocumentPolevault = itsDocument;	
}

//--------------------------------------------------------------------------------------------------
#pragma segment ARes


pascal void TPolevaultView::Draw(const VRect& dstVRect) // Override 
{
	GrafPtr oldPort;
	GrafPtr W = GetGrafPort();
	WindowPtr win;
	PaletteHandle plt;
	CTabHandle ctb;
	
	if (!fPaletteFixedYet)
	{
		if (GetWindow() != nil)
		{
			win = GetWindow()->fWMgrWindow;
			plt = GetNewPalette(128);
			if (plt)
			{
				SetPalette(win, plt, true);
				(*(((CWindowPtr)win)->portPixMap))->pmTable = fDocumentPolevault->fCTable;
			}
			else
			{
				//debugf("didn't load the palette;g");
			}
		}
		else
		{
			//debugf("tried to set palette, but view had no window;g");
		}
		fPaletteFixedYet = true;
	}
	
	GetPort(oldPort);
	SetPort(W);
	
	HLock((Handle) fDocumentPolevault->fOffGrafPtr->portPixMap);
	HLock((Handle) ((CGrafPtr) W)->portPixMap);
	
	VRect offScreenVRect((*(fDocumentPolevault->fOffGrafPtr->portPixMap))->bounds);
	
	offScreenVRect = dstVRect & offScreenVRect;

	CRect srcCRect = offScreenVRect.ToRect();
	CRect dstCRect;
	
	ViewToQDRect(offScreenVRect, dstCRect);
	
	CopyBits((BitMap&) **(fDocumentPolevault->fOffGrafPtr->portPixMap),
		(BitMap&) **(((CGrafPtr) W)->portPixMap), srcCRect, dstCRect, srcCopy, nil);


	HUnlock((Handle) fDocumentPolevault->fOffGrafPtr->portPixMap);
	HUnlock((Handle) ((CGrafPtr) W)->portPixMap);

	SetPort(oldPort);
}

//--------------------------------------------------------------------------------------------------
#pragma segment ASelCommand

pascal void TPolevaultView::DoMenuCommand(CommandNumber aCommandNumber) // Override 
{
/*
This method is overridden to handle menu items which are enabled when this view
is in the target chain. In this example, this is true when the window containing
this view is the active window. The inherited method should always be called so 
that MacApp can allow successor objects in the target chain (i.e. document and 
application) to handle THEIR menu items.
*/
	switch (aCommandNumber) 
	{
//		case cCommandHandledByView :
//			SysBeep(2);
//			break;
			
		default:
			inherited::DoMenuCommand(aCommandNumber);
			break;
	}
}

//--------------------------------------------------------------------------------------------------
#pragma segment AOpen
	
pascal void TPolevaultView::DoPostCreate(TDocument* itsDocument) // Override 
{
	inherited::DoPostCreate(itsDocument);
	
	fDocumentPolevault = (TDocumentPolevault*) itsDocument;
}
	
//--------------------------------------------------------------------------------------------------
#pragma segment ARes
			
pascal void TPolevaultView::DoSetupMenus() // Override 
{
/*
This method is overridden to enable menu items which should be enabled when this 
view is in the target chain. MacApp initially disables all menu items, then
lets the objects in the target chain enable those items they handle. 

A view is generally in the target chain when its window is the active window, and the
view or one of its subviews is designated as the target of that window. In this example,
the window's resource specifies the Mandel view as the target.
 
The inherited method is called so that objects further up the target chain (the scroller,
window, document and application) can set up THEIR menus. 
*/

	inherited::DoSetupMenus();
//	Enable(cCommandHandledByView,TRUE);
//	EnableCheck(cCommandHandledByView,TRUE,TRUE);
}

//--------------------------------------------------------------------------------------------------
#pragma segment ASelCommand

pascal void TPolevaultView::DoMouseCommand(VPoint& theMouse,
								  TToolboxEvent* /* event */,
								  CPoint /* hysteresis */)	// Override
{
	TTrackerMandel* aTracker = new TTrackerMandel;

	aTracker->ITrackerMandel(fDocumentPolevault, this, this->GetScroller(FALSE), theMouse);
	this->PostCommand(aTracker);
}
