/******************************************************************************
**
**  Project Name:	A/UX AppleEvent Suite
**     File Name:	AUX-AESuite.h
**
**   Description:	A/UX AppleEvent Suite Definition
**
*******************************************************************************
** %F%  %I%
*******************************************************************************
**
**                     Copyright (c) 1992 Apple Computer, Inc.
**                       UNPUBLISHED -- ALL RIGHTS RESERVED.
**
**  This program is  confidential  and trade secret of  Apple Computer, Inc.
**  The receipt or possession of this program does not convey any rights to
**  reproduce or disclose  its  contents, or to manufacture,  use,  or sell
**  anything that it may discribe, in whole or in part, without the express
**  written consent of Apple Computer, Inc.
**
*******************************************************************************
**                       A U T H O R   I D E N T I T Y
*******************************************************************************
**
**	Initials	Name
**	--------	-----------------------------------------------
**	BRH			Brett R. Halle
**	JSM			Scott Mulligan
**      RDW                     Roger Warner
**
*******************************************************************************
**                      R E V I S I O N   H I S T O R Y
*******************************************************************************
**
**	  Date		Time	Author	Description
**	--------	-----	------	---------------------------------------
**	06/20/92	14:24	BRH		Original implementation.
**	03/01/93	14:54	JSM		Add new AE 'rcmd'
**	07/29/93	10:00	JSM		Add new AEs for Discus
**      10/08/93        11:00   RDW             Add new keys for replies
**
******************************************************************************/

#ifndef __AUXAESuite__
#define __AUXAESuite__

/*
//const OSType keyAEText = 'ktxt';
//const long kAEReplyModeMask = 0x0000000F;// Mask for reply mode
*/

/*****************
//  Event Class  *
//****************/

#define kAEAUXSuite 'A/UX'

/*****************
//  Event Suite  *
//****************/

/* * * * * * * * * * * * * *
// Open process connection *
// * * * * * * * * * * * * */

#define kAEOpenProcessConnection 'oppc'			/* Event ID. */
/*
// Parameters:
*/
#define keyUserID 'uid '		/* User ID: typeChar. */
#define keyPassword 'pswd'		/* Password: typeChar. */
/*
// Reply parameters:
*/
#define keyConnectionID 'cnid'		/* Connection ID: typeLongInteger. */
/*		keyErrorNumber (optional)
//		keyErrorString (optional)
*/

/* * * * * * * * * * * * * *
// Open console connection *
// * * * * * * * * * * * * */

#define kAEOpenConsoleConnection 'opcc'			/* Event ID. */
/*
// Parameters:
//
//		keyUserID
//		keyPassword
//
// Reply parameters:
//
//		keyConnectionID
//		keyErrorNumber (optional)
//		keyErrorString (optional)
*/

/* * * * * * * * * * * *
// Open PTY connection *
// * * * * * * * * * * */

#define kAEOpenPTYConnection 'optc'			/* Event ID. */
/*
// Parameters:
//
//		keyUserID
//		keyPassword
//
// Reply parameters:
//
//		keyConnectionID
//		keyErrorNumber (optional)
//		keyErrorString (optional)
*/

/* * * * * * * * * * *
// Close connection  *
// * * * * * * * * * */

#define kAECloseConnection 'clsc'			/* Event ID. */
/*
// Parameters:
//
//		keyConnectionID
//
// Reply parameters:
//
//		keyErrorNumber (optional)
//		keyErrorString (optional)
*/

/* * * * * * * * * * * * *
// Close all connections *
// * * * * * * * * * * * */

#define kAECloseAllConnections 'clsa'			/* Event ID. */
/*
// Parameters:
//
//		none
//
// Reply parameters:
//
//		keyErrorNumber (optional)
//		keyErrorString (optional)
*/

/* * * * * * * * * * *
// Send process data *
// * * * * * * * * * */

#define kAESendProcessData 'data'			/* Event ID. */
/*
// Parameters:
//
//		keyConnectionID
//		keyAEText
//
// Reply parameters:
//
//		keyErrorNumber (optional)
//		keyErrorString (optional)
*/

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * 
// Acknowledge process data (asynchronous response to SendProcessData  *
// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

#define kAEAckProcessData 'ackd'			/* Event ID. */
/*
// Parameters:
//
//		keyConnectionID
//
// Reply parameters:
//
//		keyErrorNumber (optional)
//		keyErrorString (optional)
*/

/* * * * * * * * *
// Resize window *
// * * * * * * * */

#define kAEResizeWindow 'rszw'			/* Event ID. */
/*
// Parameters:
//
//		keyConnectionID
*/
#define keyWidthInChars 'wdch'			/* typeInteger. */
#define keyHeightInChars 'htch'			/* typeInteger. */
#define keyWidthInPixels 'wdpx'			/* typeInteger. */
#define keyHeightInPixels 'htpx'		/* typeInteger. */
/*
// Reply parameters:
//
//		keyErrorNumber (optional)
//		keyErrorString (optional)
*/

/* * * * * * * * * * * * * * * *
// Get number of sub-processes *
// * * * * * * * * * * * * * * */

#define kAEGetNumberOfSubprocesses 'gtsp'		/* Event ID. */
/*
// Parameters:
//
//		keyConnectionID
//
// Reply parameters:
//
//		keyAEResult
//		keyErrorNumber (optional)
//		keyErrorString (optional)
*/

/* * * * * * * * * * * *
// Get process status  *
// * * * * * * * * * * */

#define kAEProcessStatus 'gtps'				/* Event ID. */
/*
// Parameters:
//
//		keyConnectionID
//
// Reply parameters:
//
//		keyAEResult
//		keyErrorNumber (optional)
//		keyErrorString (optional)
*/

/* * * * * * * * * * * * * *
// Get process device name *
// * * * * * * * * * * * * */

#define kAEGetProcessDeviceName 'gtpd'			/* Event ID. */
/*
// Parameters:
//
//		keyConnectionID
//
// Reply parameters:
//
//		keyAEResult
//		keyErrorNumber (optional)
//		keyErrorString (optional)
*/

/* * * * * * * * * * * * * *
// Run a remote command      *
// * * * * * * * * * * * * */

#define kAERunRemoteCommand 'rcmd'			/* Event ID. */
/*
// Parameters:
//
//		keyAEText "the command to run"
//
// Reply parameters:
//
//		keyAEText "the output from the command"
//		keyErrorNumber (optional)
//		keyErrorString (optional)
*/



/*-------------------------------------------------------------------------*
 *
 *	AppleEvents for MANDELBROT      ***      AppleEvents for MANDELBROT
 *
 *-------------------------------------------------------------------------*/

#define kAEMandel 	'mndl'

/*-------------------------------------------------------------------------*
 *
 *	AppleEvents for JAVELIN      ***      AppleEvents for JAVELIN
 *
 *-------------------------------------------------------------------------*/

#define keyInterval 'tint'

#define kAEInterval 'jint'			/* Event ID. */
/*
// Parameters:
//
//      keyInterval 'tint'			// Integer
//
*/

#define kAEJavMsg 'jmsg'			/* Event ID. */
/*
// Parameters:
//      keyMessageCode	'msgc'	// typeInteger    : Error Message Number
//      keyMsgString	'msgs'	// typeChar       : Message String
//
//
*/

/*-------------------------------------------------------------------------*
 *
 *	AppleEvents for DISCUS      ***      AppleEvents for DISCUS
 *
 *-------------------------------------------------------------------------*/


/* * * * * * * * * * * * * * *
// * The NULL Event          *
// * * * * * * * * * * * * * */

#define kAENull 'null'			/* Event ID. */
/*
// Parameters:
//
//		None
//
// Reply parameters:
//
//		keyErrorNumber		// typeChar
//		keyErrorString  	// typeChar
*/

/* * * * * * * * * * * * * * *
// * The QUIT Event          *
// * * * * * * * * * * * * * */

#define kAEQuit 'quit'			/* Event ID. */
/*
// Parameters:
//
//		None
//
// Reply parameters:
//
//		None.
*/

#define kAEHeartBeat 'hart'		/* Event ID. */
/*
// Parameters:
//
//		None
//
// Reply parameters:
//
//		None.
*/

/* * * * * * * * * * * * * * *
// * The Version Event       *
// * * * * * * * * * * * * * */

#define kAEVersion 'dver'		/* Event ID. */
/*
// Parameters:
//
//		keyAEVersion		// typeChar
//
// Reply parameters:
//
//		keyErrorNumber		// typeChar
//		keyErrorString  	// typeChar
*/

/* * * * * * * * * * * * * * * * *
// * The Discus Message Event    *
// * * * * * * * * * * * * * * * */

#define kAEDiscMsg 'dmsg'		/* Event ID. */
/*
// Parameters:
//
//		keyAEMessageCode	// typeInteger
//		keyAEMsgString		// typeChar
//
// Reply parameters:
//
//		keyErrorNumber		// typeChar
//		keyErrorString  	// typeChar
*/

/* * * * * * * * * * * * * * * * *
// * The Easy-Setup Event    *
// * * * * * * * * * * * * * * * */

#define kAEEasySetup 'easy'		/* Event ID. */
/*
// Parameters:
//
//		None.
//
// Reply parameters:
//
//		keyErrorNumber		// typeChar
//		keyErrorString  	// typeChar
*/

/* * * * * * * * * * * * * * *
// * The Command Reply Event *
// * * * * * * * * * * * * * */

#define kAECmdReply 'cmdr'		/* Event ID. */
/*
// Parameters:
//
//		keyErrorNumber		// typeChar
//		keyErrorString  	// typeChar
//
// Reply parameters:
//
//		None.
*/

/* * * * * * * * * * * * * * *
// * The ChangePV Event      *
// * * * * * * * * * * * * * */

#define kAEChangePV 'chpv'		/* Event ID. */
/*
// Parameters:
//
//		keyPVAvail		// typeBool (optional)
//		keyPVAlloc		// typeBool (optional)
//
// Reply parameters:
//
//		keyErrorNumber		// typeChar
//		keyErrorString  	// typeChar
*/

/* * * * * * * * * * * * * * *
// * The ChangeVG Event      *
// * * * * * * * * * * * * * */

#define kAEChangeVG 'chvg'		/* Event ID. */
/*
// Parameters:
//
//		keyPVAvail		// typeBool (optional)
//		keyPVAlloc		// typeBool (optional)
//
// Reply parameters:
//
//		keyErrorNumber		// typeChar
//		keyErrorString  	// typeChar
*/

/* * * * * * * * * * * * * * *
// * The ChangeLV Event      *
// * * * * * * * * * * * * * */

#define kAEChangeLV 'chlv'		/* Event ID. */
/*
// Parameters:
//
//  [general attributes]
//
//		keyName			// typeChar
//		keyLVLabel		// typeChar         (optional)
//		keyLVType		// typeChar         (optional)
//		keyLVNumLPs		// typeShortInteger (optional)
//		keyLVRelo		// typeBool         (optional)
//		keyLVBBRelo		// typeBool         (optional)
//		keyLVWrVerify		// typeBool         (optional)
//		keyLVReadOnly		// typeBool         (optional)
//
//  [general attributes - increase size]
//
//		keyLVNumAddLPs		// typeShortInteger (optional)
//		keyLVISPosition		// typeShortInteger (optional)
//		keyLVISMinRange		// typeBool         (optional)
//		keyLVISMaxPVs		// typeShortInteger (optional)
//
//  [allocation policies]
//
//		keyLVMirCopies		// typeShortInteger (optional)
//		keyLVSequential		// typeBool         (optional)
//		keyLVMirConsChk		// typeBool         (optional)
//		keyLVCopiesSep		// typeBool         (optional)
//		keyPVList		// typeChar         (optional)
//		keyLVPosition		// typeShortInteger (optional)
//		keyLVMinRange		// typeBool         (optional)
//		keyLVMaxPVs		// typeShortInteger (optional)
//
// Reply parameters:
//
//		keyErrorNumber		// typeChar
//		keyErrorString  	// typeChar
*/

/* * * * * * * * * * * * * * *
// * The ChangeFS Event      *
// * * * * * * * * * * * * * */

#define kAEChangeFS 'chfs'		/* Event ID. */
/*
// Parameters:
//
//		keyFSMountPt		// typeChar
//		keyName			// typeChar         (optional) NewMtPt
//		keyFSSize		// typeInteger      (optional) NewSize
//		keyFSAutoMount		// typeBool         (optional)
//		keyFSDefRO		// typeBool         (optional)
//		keyLVMirCopies		// typeShortInteger (optional)
//		keyLVCopiesSep		// typeBool         (optional)
//
// Reply parameters:
//
//		keyErrorNumber		// typeChar
//		keyErrorString  	// typeChar
*/

/* * * * * * * * * * * * * * *
// Format a Physical Volume  *
// * * * * * * * * * * * * * */

#define kAEFormatPV 'fmpv'			/* Event ID. */
/*
// Parameters:
//
//		Unknown
//
// Reply parameters:
//
//		keyName		// typeChar 
//
// Reply parameters:
//
//		keyErrorNumber	// typeChar
//		keyErrorString  // typeChar
*/

/* * * * * * * * * * * * * * *
// Create a New Volume Group *
// * * * * * * * * * * * * * */

#define kAENewVG 'nwvg'			/* Event ID. */
/*
// Parameters:
//
//		keyVGName	// typeChar
//		keyPVList	// typeChar
//		keyVGAutoActive	// typeBoolean
//		keyVGActive	// typeBoolean
//		keyVGPPSize	// typeShortInteger
//
// Reply parameters:
//
//		keyErrorNumber	// typeChar
//		keyErrorString  // typeChar
*/

/* * * * * * * * * * * * * * *
// Rename a Volume Group     *
// * * * * * * * * * * * * * */

#define kAERenameVG 'rnvg'			/* Event ID. */
/*
// Parameters:
//
//		Unknown
//
// Reply parameters:
//
//		Unknown
//		Unknown (optional)
//		Unknown (optional)
*/

/* * * * * * * * * * * * * * *
// ReOrg a Volume Group     *
// * * * * * * * * * * * * * */

#define kAEReOrgVG 'rgvg'			/* Event ID. */
/*
// Parameters:
//
//		Unknown
//
// Reply parameters:
//
//		Unknown
//		Unknown (optional)
//		Unknown (optional)
*/
/* * * * * * * * * * * * * * *
// Remove a Volume Group     *
// * * * * * * * * * * * * * */

#define kAERemoveVG 'rmvg'			/* Event ID. */
/*
// Parameters:
//
//		keyName				// typeChar
//		keyPVList			// typeChar
//
// Reply parameters:
//
//		keyErrorNumber			// typeChar
//		keyErrorString			// typeChar
*/

/* * * * * * * * * * * * * * *
// Create a new File System  *
// * * * * * * * * * * * * * */

#define kAENewFS 'nwfs'			/* Event ID. */
/*
// Parameters:
//
//		keyVFSType			// typeChar
//		keyVGName			// typeChar
//		keyFSSize			// typeInteger
//		keyFSMountPt			// typeChar
//		keyFSAutoMount			// typeBoolean
//		keyFSDefRO			// typeBoolean
//		keyFSDiskAcct			// typeBoolean
//		keyFSOptions			// typeChar
//		keyFSMountNow			// typeBoolean
//
// Reply parameters:
//
//		keyErrorNumber			// typeChar
//		keyErrorString			// typeChar
*/

/* * * * * * * * * * * * * * *
// Rename a File System      *
// * * * * * * * * * * * * * */

#define kAERenameFS 'rnfs'			/* Event ID. */
/*
// Parameters:
//
//		Unknown
//
// Reply parameters:
//
//		Unknown
//		Unknown (optional)
//		Unknown (optional)
*/

/* * * * * * * * * * * * * * *
// Remove a File System      *
// * * * * * * * * * * * * * */

#define kAERemoveFS 'rmfs'			/* Event ID. */
/*
// Parameters:
//
//		keyName (the FS name)
//		keyLVvgname
//
// Reply parameters:
//
//		Unknown
//		Unknown (optional)
//		Unknown (optional)
*/

/* * * * * * * * * * * * * * * * * * * * * *
// Add a Physcial Volume to a Volume Group *
// * * * * * * * * * * * * * * * * * * * * */

#define kAEAddPVtoVG 'pvvg'			/* Event ID. */
/*
// Parameters:
//
//		keyPVName
//		keyVGName
//
// Reply parameters:
//
//		Unknown
//		Unknown (optional)
//		Unknown (optional)
*/

/* * * * * * * * * * * * * * * * * * * * * *
// Add a Physcial Volume to a File System  *
// * * * * * * * * * * * * * * * * * * * * */

#define kAEAddPVtoFS 'pvfs'			/* Event ID. */
/*
// Parameters:
//
//		keyPVName
//		keyName (the LV name)
//
// Reply parameters:
//
//		Unknown
//		Unknown (optional)
//		Unknown (optional)
*/

/* * * * * * * * * * * * * * * * * * * * * * * * *
// Remove a Physical Volume from a Volume Group  *
// * * * * * * * * * * * * * * * * * * * * * * * */

#define kAERemovePVfromVG 'rmpv'		/* Event ID. */
/*
// Parameters:
//
//		keyPVName
//		keyVGName
//
// Reply parameters:
//
//		Unknown
//		Unknown (optional)
//		Unknown (optional)
*/

/* * * * * * * * * * * * * * * * * * * * *
// Migrate Data off of a Physical Volume *
// * * * * * * * * * * * * * * * * * * * */

#define kAEMigrateData 'mipv'			/* Event ID. */
/*
// Parameters:
//
//		Unknown
//
// Reply parameters:
//
//		Unknown
//		Unknown (optional)
//		Unknown (optional)
*/

/* * * * * * * * * * * * * * * * *
// Is Physical Volume Available? *
// * * * * * * * * * * * * * * * */

#define kAEPVavailable 'pvav'			/* Event ID. */
/*
// Parameters:
//
//		keyPVAvail
//
// Reply parameters:
//
//		Unknown
//		Unknown (optional)
//		Unknown (optional)
*/

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
// Allow allocation of physical partitions on Physical Volume?   *
// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

#define kAEPVallocate 'pval'			/* Event ID. */
/*
// Parameters:
//
//		keyPVAlloc
//
// Reply parameters:
//
//		Unknown
//		Unknown (optional)
//		Unknown (optional)
*/

/* * * * * * * * * * * * * * * * * * * *
// Mount a File System                 *
// * * * * * * * * * * * * * * * * * * */

#define kAEMountFS ' mnt'			/* Event ID. */
/*
// Parameters:
//
//		keyFSMountPt	/* Required: typeChar
//              keyFSDevice	/* Optional: typeChar
//              keyFSOptions	/* Optional: typeChar
//
// Reply parameters:
//
//		keyErrorNumber
//		keyErrorString
*/

/* * * * * * * * * * * * * * * * * * * *
// Unmount a File System               *
// * * * * * * * * * * * * * * * * * * */

#define kAEUnmountFS 'umnt'			/* Event ID. */
/*
// Parameters:
//
//		keyFSMountPt	/* Required: typeChar
//
// Reply parameters:
//
//		keyErrorNumber
//		keyErrorString
*/

/* * * * * * * * * * * * * * * * * * * *
// Set mount point for a File System   *
// * * * * * * * * * * * * * * * * * * */

#define kAESetMountPoint 'fsmt'			/* Event ID. */
/*
// Parameters:
//
//		Unknown
//
// Reply parameters:
//
//		Unknown
//		Unknown (optional)
//		Unknown (optional)
*/

/* * * * * *  * * * * * * * * * *
// Set Logname for File System  *
// * * * * *  * * * * * * * * * */

#define kAESetLogname 'fslg'			/* Event ID. */
/*
// Parameters:
//
//		Unknown
//
// Reply parameters:
//
//		Unknown
//		Unknown (optional)
//		Unknown (optional)
*/

/* * * * * * * * * * * * * * * * * * * * * *
// Set AutomountAtStartup for File System  *
// * * * * * * * * * * * * * * * * * * * * */

#define kAEAutoMount 'fsam'			/* Event ID. */
/*
// Parameters:
//
//		Unknown
//
// Reply parameters:
//
//		Unknown
//		Unknown (optional)
//		Unknown (optional)
*/

/* * * * * * * * * * * * * * * *
// Set FileSystem to ReadOnly  *
// * * * * * * * * * * * * * * */

#define kAEReadOnlyFS 'fsro'			/* Event ID. */
/*
// Parameters:
//
//		keyFSxxx
//
// Reply parameters:
//
//		Unknown
//		Unknown (optional)
//		Unknown (optional)
*/

/* * * * * * * * * * * * * * * *
// Set name of Logical Volume  *
// * * * * * * * * * * * * * * */

#define kAERemoveLV 'rmlv'			/* Event ID. */
/*
// Parameters:
//
//		keyName (the LV name)		// typeChar
//		keyLVvgname (the LV name)		// typeChar
//
// Reply parameters:
//
//		Unknown
//		Unknown (optional)
//		Unknown (optional)
*/

/* * * * * * * * * * * * * * * *
// Set name of Logical Volume  *
// * * * * * * * * * * * * * * */

#define kAENameLV 'lvnm'			/* Event ID. */
/*
// Parameters:
//
//		Unknown
//
// Reply parameters:
//
//		Unknown
//		Unknown (optional)
//		Unknown (optional)
*/

/* * * * * * * * * * * * * * * * *
// Set label for Logical Volume  *
// * * * * * * * * * * * * * * * */

#define kAELabelLV 'lvlb'			/* Event ID. */
/*
// Parameters:
//
//		Unknown
//
// Reply parameters:
//
//		Unknown
//		Unknown (optional)
//		Unknown (optional)
*/

/* * * * * * * * * * * * * * * * *
// Set type for Logical Volume   *
// * * * * * * * * * * * * * * * */

#define kAETypeLV 'lvtp'			/* Event ID. */
/*
// Parameters:
//
//		Unknown
//
// Reply parameters:
//
//		Unknown
//		Unknown (optional)
//		Unknown (optional)
*/

/* * * * * * * * * * * *
// Relocate Bad Blocks *
// * * * * * * * * * * */

#define kAEReloBadBlks 'rebb'			/* Event ID. */
/*
// Parameters:
//
//		Unknown
//
// Reply parameters:
//
//		Unknown
//		Unknown (optional)
//		Unknown (optional)
*/

/* * * * * * * * * * * * * * * * * * * * * *
// Allow Relocation during Reorganization  *
// * * * * * * * * * * * * * * * * * * * * */

#define kAEReloReorg 'rere'			/* Event ID. */
/*
// Parameters:
//
//		Unknown
//
// Reply parameters:
//
//		Unknown
//		Unknown (optional)
//		Unknown (optional)
*/

/* * * * * * * * * * * *
// Read Verify Writes  *
// * * * * * * * * * * */

#define kAEReadVerifyWrites 'rvwr'			/* Event ID. */
/*
// Parameters:
//
//		Unknown
//
// Reply parameters:
//
//		Unknown
//		Unknown (optional)
//		Unknown (optional)
*/

/* * * * * * * * * * * * * * *
// Mirror Write Consistancy  *
// * * * * * * * * * * * * * */

#define kAEMirrorWrite 'mwrc'			/* Event ID. */
/*
// Parameters:
//
//		Unknown
//
// Reply parameters:
//
//		Unknown
//		Unknown (optional)
//		Unknown (optional)
*/

/* * * * * * * * * * * * * * *
// Set max pvs for newalloc  *
// * * * * * * * * * * * * * */

#define kAEMaxPVS 'mxna'			/* Event ID. */
/*
// Parameters:
//
//		Unknown
//
// Reply parameters:
//
//		Unknown
//		Unknown (optional)
//		Unknown (optional)
*/

/* * * * * * * * * * * * * * * * * * * * * * * * * *
// Set maximum for allocation to a Logical Volume  *
// * * * * * * * * * * * * * * * * * * * * * * * * */

#define kAEMaxAllocToLV 'mxal'			/* Event ID. */
/*
// Parameters:
//
//		Unknown
//
// Reply parameters:
//
//		Unknown
//		Unknown (optional)
//		Unknown (optional)
*/

/* * * * * * * * * * * * * * * *
// Set Logical Partition size  *
// * * * * * * * * * * * * * * */

#define kAESetLPsize 'lpsz'			/* Event ID. */
/*
// Parameters:
//
//		Unknown
//
// Reply parameters:
//
//		Unknown
//		Unknown (optional)
//		Unknown (optional)
*/

/* * * * * * * * * * * * * * * *
// Set number of Mirror Copies *
// * * * * * * * * * * * * * * */

#define kAEMirrorCopies 'micp'			/* Event ID. */
/*
// Parameters:
//
//		Unknown
//
// Reply parameters:
//
//		Unknown
//		Unknown (optional)
//		Unknown (optional)
*/

/* * * * * * * * * * * * * * * * *
// Logical Partition Allocation  *
// * * * * * * * * * * * * * * * */

#define kAELogicalPartAlloc 'lpal'			/* Event ID. */
/*
// Parameters:
//
//		Unknown
//
// Reply parameters:
//
//		Unknown
//		Unknown (optional)
//		Unknown (optional)
*/

/* * * * * * * * * * * * * * * * * *
// Set Logical Volume to ReadOnly  *
// * * * * * * * * * * * * * * * * */

#define kAEReadOnlyLV 'lvro'			/* Event ID. */
/*
// Parameters:
//
//		Unknown
//
// Reply parameters:
//
//		Unknown
//		Unknown (optional)
//		Unknown (optional)
*/

/* * * * * * * * * * * * * * * *
// Set AutoActivate on Startup *
// * * * * * * * * * * * * * * */

#define kAEAutoActivate 'aast'			/* Event ID. */
/*
// Parameters:
//
//		keyVGName       	Name of VG to act upon
//		keyVGAutoActivate     	If TRUE set AutoActivate ON
//		                	If FALSE set AutoActivate OFF
//
// Reply parameters:
//
//		keyAEText	"S"  -or-
//				"Ffailmessage"
*/

/* * * * * * * * * * * * * * *
// Activate Volume Group Now *
// * * * * * * * * * * * * * */

#define kAEActivateVG 'anow'			/* Event ID. */
/*
// Parameters:
//
//		keyVGName	Name of VG to activate
//
// Reply parameters:
//
//		keyAEText	"S"  -or-
//				"Ffailmessage"
*/

/* * * * * * * * * * * * * * * *
// Deactivate Volume Group Now *
// * * * * * * * * * * * * * * */

#define kAEDeactivateVG 'dnow'			/* Event ID. */
/*
// Parameters:
//
//		keyVGName	Name of VG to deactivate
//
// Reply parameters:
//
//		keyAEText	"S"  -or-
//				"Ffailmessage"
*/

/* * * * * * * * * * * * * * * * * * * *
// Send Config Data                    *
// * * * * * * * * * * * * * * * * * * */
#define kAEConfigData 'cnfg'			/* Event ID. */
/*
// Parameters:
//
//		???	        ???
//
// Reply parameters:
//
//		???      	???
*/



/*** Parameter Keys for Discus ***/

#define keyAEVersion	'verx'	/* typeChar       : Software Version         */
#define keySessionID	'ssID'	/* typeInteger    : Session/Document ID      */

/** Parameters used by kAEDiscMsg **/
#define keyMessageCode	'msgc'	/* typeInteger    : Discus Message Number    */
#define keyMsgString	'msgs'	/* typeChar       : Optional Message String  */


/** VFS Parameters **/
#define	keyVFSType	'vfst'	/* typeChar        */

/** File System Parameters - Object attributes **/
#define keyFSList	'fsls'  /* typeChar        : <sp> delim'd list of FSs */
#define	keyDirty	'dirt'  /* typeShortInteger: New, Update, Delete      */
#define	keyFSMountPt	'fsmp'  /* typeChar        : path to mount point      */
#define	keyFSDevice	'fsdv'  /* typeChar        : path to device file      */
#define	keyFSType	'fstp'  /* typeChar        : ???                      */
#define	keyFSOptions	'fsop'  /* typeChar        : Filesytem options        */
#define	keyFSAutoMount	'fsam'  /* typeBoolean     : Automount at sys restart */
#define	keyFSDiskAcct	'fsda'  /* typeBoolean     : Disk accounting          */
#define	keyFSSize	'fssz'  /* typeInteger     : Size of file system  (Mb)*/
#define keyFSFree       'fsfr'  /* typeInteger     : Amount of free space (Mb)*/
#define keyFSMounted    'fsmt'  /* typeBoolean     : Currently mounted        */
#define	keyFSDefLogname	'fsdl'  /* typeChar        : Default name of logdevice*/
#define	keyFSCurLogname	'fscl'  /* typeChar        : Current name of logdevice*/
#define keyFSDefRO      'fsdr'  /* typeBoolean     : Currently Read-Only      */
#define keyFSCurRO      'fscr'  /* typeBoolean     : Read-Only is default     */
#define keyFSGroup      'fsgr'  /* typeChar        : Mount group we belong to */
#define keyFSBytesInode 'byte'  /* typeInteger     : Number of BytesPerInode  */
#define keyFSFragsBlock 'frag'  /* typeInteger     : Number of FragsPerBlock  */
#define keyFSCompress   'comp'  /* typeBoolean     : Compression (TRUE=on)    */



/** Logical Volume Parameters - Object attributes **/
#define keyLVList	'lvls'  /* typeChar        : <sp> delim'd list of LVs */
/*	keyDirty	'dirt'  /* typeShortInteger: New, Update, Delete      */
#define	keyName		'name'  /* typeChar        : LV Name                  */
#define	keyLVvgname	'lvvg'  /* typeChar        : Name of VG we belong to  */
#define	keyLVLabel	'lvlb'  /* typeChar        : LV Label                 */
#define	keyLVType	'lvtp'  /* typeChar        : LV Type (jfs,paging,etc.)*/
#define	keyLVIdentifier	'lvid'  /* typeChar        : LV Identifier            */
#define	keyLVState	'lvst'  /* typeChar        : LV State                 */
#define	keyLVMountPt	'lvmp'  /* typeChar        : LV Mount Point           */
#define	keyLVSize	'lvsz'  /* typeInteger     : LV Size (Mb)             */
#define	keyLVPPSize	'lvpp'  /* typeShortInteger: PP Size (Mb)             */
#define	keyLVNumLPs	'lvnl'  /* typeShortInteger: Number of Logical Part.s */
#define	keyLVNumPPs	'lvnp'  /* typeShortInteger: Number of Physical Part.s*/
#define	keyLVStalePPs	'lvsp'  /* typeShortInteger: Number of Stale PPS      */
#define	keyLVMaxLPs	'lvml'  /* typeInteger     : Maximum Number of LPS    */
#define	keyLVRelo	'lvre'  /* typeBoolean     : LV is relocatable        */
#define	keyLVBBRelo	'lvbb'  /* typeBoolean     : LV BadBlks relocatable   */
#define	keyLVWrVerify	'lvwv'  /* typeBoolean     : Write Verify             */
#define	keyLVReadOnly	'lvro'  /* typeBoolean     : LV is Read-Only          */
#define	keyLVMirCopies	'lvmc'  /* typeShortInteger: Number of Mirror Copies  */
#define	keyLVSequential	'lvsq'  /* typeBoolean     : Writes are sequential    */
#define	keyLVMirConsChk	'lvmc'  /* typeBoolean     : Mirror Write Consist Chk */
#define	keyLVCopiesSep	'lvcs'  /* typeBoolean     : Copies on seperte volumes*/
#define	keyLVPosition	'lvpo'  /* typeShort       : Position on Phys Vol.    */
#define	keyLVMinRange	'lvra'  /* typeBoolean     : Min Range of Phys Vols. */
#define	keyLVMaxPVs	'lvmx'  /* typeShort       : Max Num of Phys Vols.    */

/** More Logical Volume Parameters - Object attributes **/
/** NOTE: These attributes are used when increasing the size of an LP **/
#define	keyLVAddNumLPs	'lval'  /* typeShortInteger: Number of Additional LPs */
#define	keyLVISPosition	'lvip'  /* typeShort       : Position on Phys Vol.    */
#define	keyLVISMinRange	'lvim'  /* typeBoolean     : Min Range of Phys Vols. */
#define	keyLVISMaxPVs	'lvix'  /* typeShort       : Max Num of Phys Vols.    */
#define keyLVISPVList	'pvl2'  /* typeChar        : <sp> dilim'd list of PVs */

/** Physical Volume Parameters - Object attributes **/
#define keyPVList	'pvls'  /* typeChar        : <sp> dilim'd list of PVs */
/*	keyDirty	'dirt'  /* typeShortInteger: New, Update, Delete      */
/*      keyName		'name'  /* typeChar        : PV Name                  */
#define keyPVIdentifier	'pvid'  /* typeChar        : PV Identifier            */
#define keyPVvgname	'pvvg'  /* typeChar        : Name of VG we belong to  */
#define keyPVSize	'pvsz'  /* typeInteger     : PV Size (Mb)             */
#define keyPVFree	'pvfr'  /* typeInteger     : Amount of free space (Mb)*/
#define keyPVUsed	'pvus'  /* typeInteger     : Amount of used space (Mb)*/
#define keyPVPPSize	'pvpz'  /* typeShortInteger: Size of Phys Partitions  */
#define keyPVBusID	'pvbi'  /* typeShortInteger: ID of SCSI Bus           */
#define keyPVScsiID	'pvsi'  /* typeShortInteger: SCSI ID of Disk          */
#define keyPVLUN	'pvlu'  /* typeShortInteger: LogicalUnitNumber of Disk*/
#define keyPVRaid	'pvra'  /* typeBoolean     : Is a RAID Disk Array     */
#define keyPVAvail	'pvav'  /* typeBoolean     : Is Available             */
#define keyPVAlloc	'pval'  /* typeBoolean     : Is Alocatable            */


/** Volume Group Parameters - Object attributes **/
#define keyVGList	'vgls'  /* typeChar        : <sp> dilim'd list of VGs */
/*	keyDirty	'dirt'  /* typeShortInteger: New, Update, Delete      */
/*	keyName		'name'  /* typeChar        : VG Name                  */
#define	keyVGActive	'vgac'  /* typeBoolean     : Is Active                */
#define	keyVGReadOnly	'vgro'  /* typeBoolean     : Is Read-Only             */
#define	keyVGMaxLVs	'vgml'  /* typeShortInteger: Maximum Number of LVs    */
#define	keyVGNumLVs	'vgnl'  /* typeShortInteger: Number of LVs            */
#define	keyVGNumOpenLVs	'vgol'  /* typeShortInteger: Number of open LVs       */
#define	keyVGNumPVs	'vgnp'  /* typeShortInteger: Number of PVs            */
#define	keyVGStalePVs	'vgsp'  /* typeShortInteger: Number of Stale PVs      */
#define	keyVGActivePVs	'vgap'  /* typeShortInteger: Number of Active PVs     */
#define	keyVGIdentifier	'vgid'  /* typeChar        : VG Identifier            */
#define	keyVGPPSize	'vgpz'  /* typeShortInteger: Size of Phys Partitions  */
#define	keyVGSize	'vgsz'  /* typeInteger     : VG Size (Mb)             */
#define	keyVGFree	'vgfr'  /* typeInteger     : Amount of free space (Mb)*/
#define	keyVGUsed	'vgus'  /* typeInteger     : Amount of used space (Mb)*/
#define	keyVGQuorum	'vgqu'  /* typeShortInteger: Number for quorum        */
#define	keyVGDescript	'vgde'  /* typeShortInteger: Number of VG descriptors */
#define	keyVGStalePPs	'vgsp'  /* typeShortInteger: Number of Stale PPs      */
#define	keyVGAutoActive	'vgaa'  /* typeBoolean     : AutoActivate             */




/* Used by HandleSetMntPoint */
#define	keyFSNewMntPt	'fsnm'  /* typeChar        */

/* Used by HandleNewFS() */
#define	keyFSMountNow	'mnow'  /* typeBoolean     */

/* Used by HandleRemoveFS() */
#define	keyFSRemoveMtPt	'fsrm'  /* typeBoolean     */

/* Used by HandleAddPVtoVG() */
#define keyPVName	'pvnm'  /* typeChar        */

/* Used by HandleRemovePVfromVG() */
#define keyForceDealloc	'forc'  /* typeBoolean     : Flag to force dealloc    */

#endif  /* __AUXAESuite__ */


